==> apache-cloudstack-4.19.2.0-src.tar.bz2: apache-cloudstack-4.19.2.0-src/engine/storage/integration-test/src/test/java/org/apache/cloudstack/storage/test/MockRpcCallBack.java <==
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.
package org.apache.cloudstack.storage.test;

import javax.inject.Inject;

import org.apache.log4j.Logger;

import org.apache.cloudstack.framework.async.AsyncCompletionCallback;

import com.cloud.agent.AgentManager;
import com.cloud.agent.api.Answer;
import com.cloud.agent.api.Command;
import com.cloud.utils.db.DB;

public class MockRpcCallBack implements Runnable {
    private static final Logger s_logger = Logger.getLogger(MockRpcCallBack.class);
    @Inject
    AgentManager agentMgr;
    private Command cmd;
    private long hostId;
    private AsyncCompletionCallback<Answer> callback;

    public void setCmd(Command cmd) {
        this.cmd = cmd;
    }

    public void setHostId(long hostId) {
        this.hostId = hostId;
    }

    public void setCallback(AsyncCompletionCallback<Answer> callback) {
        this.callback = callback;
    }

    @Override
    @DB
    public void run() {
        try {
            Answer answer = agentMgr.send(hostId, cmd);
            callback.complete(answer);
        } catch (Throwable e) {
            s_logger.debug("send command failed:", e);
        }
    }

}

==> apache-cloudstack-4.21.0.0-src.tar.bz2: apache-cloudstack-4.21.0.0-src/engine/storage/integration-test/src/test/java/org/apache/cloudstack/storage/test/MockRpcCallBack.java <==
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.
package org.apache.cloudstack.storage.test;

import javax.inject.Inject;

import org.apache.logging.log4j.Logger;
import org.apache.logging.log4j.LogManager;

import org.apache.cloudstack.framework.async.AsyncCompletionCallback;

import com.cloud.agent.AgentManager;
import com.cloud.agent.api.Answer;
import com.cloud.agent.api.Command;
import com.cloud.utils.db.DB;

public class MockRpcCallBack implements Runnable {
    protected Logger logger = LogManager.getLogger(getClass());
    @Inject
    AgentManager agentMgr;
    private Command cmd;
    private long hostId;
    private AsyncCompletionCallback<Answer> callback;

    public void setCmd(Command cmd) {
        this.cmd = cmd;
    }

    public void setHostId(long hostId) {
        this.hostId = hostId;
    }

    public void setCallback(AsyncCompletionCallback<Answer> callback) {
        this.callback = callback;
    }

    @Override
    @DB
    public void run() {
        try {
            Answer answer = agentMgr.send(hostId, cmd);
            callback.complete(answer);
        } catch (Throwable e) {
            logger.debug("send command failed:", e);
        }
    }

}
